#+ pplane_key.gp
# This file was written by Jonathan A. Sherratt
# Copyright (C) 2011 Heriot-Watt University, Edinburgh, UK
#  
# THIS FILE IS PART OF WAVETRAIN.
# WAVETRAIN SOFTWARE IS INTENDED FOR FREE PERSONAL PRIVATE 
# AND ACADEMIC USE ONLY AND WAS DEVELOPED BY JONATHAN SHERRATT AT 
# HERIOT-WATT UNIVERSITY, EDINBURGH, UK, AND IS PROTECTED BY COPYRIGHT. 
# THE COPYRIGHT OWNER IS HERIOT-WATT UNIVERSITY, WITH THE EXCEPTION OF 
# THE ROUTINES FROM THE PACKAGES AUTO, BLAS, EISPACK, LAPACK AND MINPACK, 
# WHICH ARE INCLUDED WITH PERMISSION, WHICH ARE CLEARLY IDENTIFIED IN 
# THE SOURCE CODE, AND THE USE OF THESE PACKAGES IS UNDER THE CONDITIONS 
# OF THE ORIGINAL OWNERS WHICH ARE AVAILABLE AT 
# http://www.netlib.org/blas/faq.html#2;
# http://www.netlib.org/lapack/#_licensing; 
# http://www.netlib.org/minpack/disclaimer.
# 
# PERSONS OR ORGANISATIONS WISHING TO USE THIS WAVETRAIN SOFTWARE FOR 
# COMMERCIAL PURPOSES OR PURPOSES OTHER THAN ITS ORIGINAL INTENTION 
# SHOULD CONTACT THE OWNERS TO REQUEST SPECIFIC WRITTEN PERMISSIONS.
# 
# DISTRIBUTION: DISTRIBUTION OF WAVETRAIN SOFTWARE, IN PART OR AS 
# A WHOLE, BY ANY MEANS (ELECTRONIC, PRINTED COPY OR OTHERWISE), IS 
# PROHIBITED WITHOUT THE PRIOR WRITTEN PERMISSION OF EITHER HERIOT-WATT 
# UNIVERSITY OR THE AUTHOR JONATHAN A. SHERRATT. ALL REQUESTS FOR SUCH 
# PERMISSION SHOULD BE SENT BY EMAIL TO J.A.SHERRATT@HW.AC.UK; PLEASE 
# INCLUDE THE WORD WAVETRAIN IN THE SUBJECT HEADING OF THE MESSAGE.  
# 
# WARRANTY LIMITATIONS: THE PRODUCT AND SERVICE ARE PROVIDED "AS IS". 
# THE OWNER DISCLAIMS ANY AND ALL WARRANTIES, INCLUDING BUT NOT LIMITED 
# TO, ALL EXPRESSED OR IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE. UNDER NO CIRCUMSTANCES WILL THE OWNER BE 
# LIABLE TO YOU FOR ANY LOSS OF USE, INTERRUPTION OF BUSINESS OR ANY 
# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, AND/OR CONSEQUENTIAL DAMAGES 
# OF ANY KIND (INCLUDING LOSS OF PROFITS) EVEN IF THE OWNER HAS BEEN 
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. THE OWNER ACCEPTS NO LEGAL 
# LIABILITY FOR ANY OF THE PRODUCT AND/OR SERVICE SOLD, OFFERED FOR SALE, 
# OR OTHERWISE MADE AVAILABLE FOR PUBLIC OR PRIVATE CONSUMPTION IN 
# RELATION TO THIS SOFTWARE. THE OWNER DOES NOT WARRANT THAT THIS SOFTWARE 
# WILL BE ERROR-FREE.
#  
#+ THIS gnuplot COMMAND FILE GENERATES A KEY TO INDICATE THE 
#+ MEANING OF THE VARIOUS COLOURS/SYMBOLS/LINE STYLES IN PLOTS
#+ OF THE CONTROL PARAMETER-WAVE SPEED PLANE. NOTE THAT THE KEY 
#+ ALWAYS SHOWS SYMBOLS CORRESPONDING TO THE OUTCOME OF THE
#+ CALCULATIONS. THE PLOTTING COMMAND @pplane ALSO ENABLES PLOTS
#+ USING WAVE PERIODS OR RCODE VALUES, BUT IT IS ASSUMED THAT 
#+ THESE WILL ONLY BE BE USED TO ASSIST IN DOING OTHER PLOTS 
#+ AND IN DETERMINING  ADDITIONAL CALCULATIONS, RATHER THAN FOR 
#+ PRESENTATIONAL PURPOSES, MAKING IT UNNECESSARY TO PROVIDE 
#+ SPECIFIC KEYS FOR THESE OTHER CASES.
#++
if ($#>0) print "ERROR: no arguments are expected" ; exit
unset label
unset xlabel
unset ylabel
unset multiplot ; mpon="no"
unset xzeroaxis
unset yzeroaxis
set tics nooffset
nkey=words(pplanekeylist)
set size 0.9,0.9
set origin 0.05,0.05
set xrange [0:100]
set yrange [0:100]
ncharsmax=0 # max number of characters in the text label associated with a key item
ikey=1 # index for item number in the list of key items
keylinecmd="" #initialisation
y=100 # initialisation
check4and5=0 # initialisation
xpoint=pplanekeygaplength+0.5*pplanekeylinelength
xtext=2*pplanekeygaplength+pplanekeylinelength
xline1=pplanekeygaplength
xline2=pplanekeygaplength+pplanekeylinelength
ifirst=0
load "pplane_key_nextitem.gp"
characterwidth=100.0/(0.9*canvaswidthchars) 
# This is an estimate of the average width of one character, in graph
#   coordinates, for the basic font selected when the terminal is
#   specified. The 0.9 comes from the size specification.
xmax=xtext+ncharsmax*pplanekeytextfactor*characterwidth+pplanekeygaplength
if (xmax>100) xmax=100 ; \
 print "WARNING: the key for the control parameter--wave speed plot" ; \
 print "         does not fit into the surrounding box." ; \
 print "         The simplest remedy is to reduce the value" ; \
 print "         of pplanekeytextexpand, set in plot_defaults.input" ; \
 print "         If this message appears even though the key is" ; \
 print "         actually fitting into the box, this indicates that" ; \
 print "         the value of screenwidthchars (set in plot_defaults.input)" ; \
 print "         is too small."
yboxmin=y-0.5*pplanekeylineseparation
yboxmax=100-0.5*pplanekeylineseparation
system "create_box_data.script data_files/keybox.data 0.0 ".gprintf("%18.10g",yboxmin)." ".gprintf("%18.10g",xmax)." ".gprintf("%18.10g",yboxmax)
unset xlabel
unset ylabel
unset tics
unset border
plot "data_files/keybox.data" using 1:2 with lines @linethickness linetype -1 \
 linecolor rgb "black"@keylinecmd
set border 4095 front @linethickness linetype -1 linecolor rgb "black"
# the above command restores the border setting to that specified in plot.script
set tics
